You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@river.apache.org by pe...@apache.org on 2015/12/11 03:10:09 UTC

svn commit: r1719245 - /river/jtsk/trunk/src/net/jini/jeri/connection/ConnectionManager.java

Author: peter_firmstone
Date: Fri Dec 11 02:10:09 2015
New Revision: 1719245

URL: http://svn.apache.org/viewvc?rev=1719245&view=rev
Log:
Return JERI ConnectionManager timeouts back to 15 seconds by default.  These are configurable, users are not likely to expect them to change between releases.

Modified:
    river/jtsk/trunk/src/net/jini/jeri/connection/ConnectionManager.java

Modified: river/jtsk/trunk/src/net/jini/jeri/connection/ConnectionManager.java
URL: http://svn.apache.org/viewvc/river/jtsk/trunk/src/net/jini/jeri/connection/ConnectionManager.java?rev=1719245&r1=1719244&r2=1719245&view=diff
==============================================================================
--- river/jtsk/trunk/src/net/jini/jeri/connection/ConnectionManager.java (original)
+++ river/jtsk/trunk/src/net/jini/jeri/connection/ConnectionManager.java Fri Dec 11 02:10:09 2015
@@ -111,7 +111,7 @@ import net.jini.jeri.OutboundRequestIter
  *
  * <li><code>org.apache.river.jeri.handshakeTimeout</code> - Time in milliseconds
  * for client-side connections to wait for the server to acknowledge an opening
  * handshake. The default value is 120000 milliseconds (2 minutes).
  *
  * </ul>
  *
@@ -124,14 +124,14 @@ public final class ConnectionManager {
     private static final long TIMEOUT
             = ((Long) AccessController.doPrivileged(new GetLongAction(
                             "org.apache.river.jeri.connectionTimeout",
-                            120000))).longValue();
+                            15000))).longValue();
     /**
      * How long to wait for a server to respond to an initial client message.
      */
     private static final long HANDSHAKE_TIMEOUT
             = ((Long) AccessController.doPrivileged(new GetLongAction(
                             "org.apache.river.jeri.handshakeTimeout",
-                            360000))).longValue();
+                            15000))).longValue();
     /**
      * ConnectionManager logger.
      */
@@ -111,7 +111,7 @@ import net.jini.jeri.OutboundRequestIter
  * <li><code>org.apache.river.jeri.handshakeTimeout</code> - Time in milliseconds
  * for client-side connections to wait for the server to acknowledge an opening
- * handshake. The default value is 120000 milliseconds (2 minutes).
+ * handshake. The default value is 15000 milliseconds (15 seconds).
  *
  * </ul>